@@ -36,6 +36,7 @@ class BlockParser(object):
         self.implementations = []
         self.line_parsers = {
             'SCENARIO': self.parse_scenario,
+            'ASSUMING': self.parse_assuming,
             'GIVEN': self.parse_given,
             'WHEN': self.parse_when,
             'THEN': self.parse_then,
@@ -86,6 +87,9 @@ class BlockParser(object):
         self.scenarios[-1].steps.append(step)
         return blocks
 
+    def parse_assuming(self, line, blocks):
+        return self.parse_simple('ASSUMING', line, blocks)
+
     def parse_given(self, line, blocks):
         return self.parse_simple('GIVEN', line, blocks)
 
