@@ -16,9 +16,9 @@
 # =*= License: GPL-3+ =*=
 
 
-# This is a step in a story: GIVEN, WHEN, THEN, etc.
+# This is a step in a scenario: GIVEN, WHEN, THEN, etc.
 
-class StoryStep(object):
+class ScenarioStep(object):
 
     def __init__(self, what, text):
         self.what = what
@@ -26,9 +26,9 @@ class StoryStep(object):
         self.implementation = None
 
 
-# This is the story itself.
+# This is the scenario itself.
 
-class Story(object):
+class Scenario(object):
 
     def __init__(self, name):
         self.name = name
